@@ -89,13 +89,13 @@ if [ ! -d "${fireqos_run_dir}" ]; then
 			if [ -d "${LOCALSTATEDIR}/run/fireqos" ]; then
 				fireqos_run_dir="${LOCALSTATEDIR}/run/fireqos"
 			else
-				warning "FireQoS is installed as '${fireqos}', its installation config at '${fireqos_exec_dir}/install.config' specifies local state data at '${LOCALSTATEDIR}/run/fireqos', but this directory is not found or is not readable (check the permissions of its parents)."
+				warning "FireQOS is installed as '${fireqos}', its installation config at '${fireqos_exec_dir}/install.config' specifies local state data at '${LOCALSTATEDIR}/run/fireqos', but this directory is not found or is not readable (check the permissions of its parents)."
 			fi
 		else
-			warning "Although FireQoS is installed on this system as '${fireqos}', I cannot find/read its installation configuration at '${fireqos_exec_dir}/install.config'."
+			warning "Although FireQOS is installed on this system as '${fireqos}', I cannot find/read its installation configuration at '${fireqos_exec_dir}/install.config'."
 		fi
 	else
-		warning "FireQoS is not installed on this system. Use FireQoS to apply traffic QoS and expose the class names to netdata. Check https://github.com/netdata/netdata/tree/master/collectors/tc.plugin#tcplugin"
+		warning "FireQOS is not installed on this system. Use FireQOS to apply traffic QoS and expose the class names to netdata. Check https://github.com/netdata/netdata/tree/master/collectors/tc.plugin#tcplugin"
 	fi
 fi
 
@@ -291,7 +291,7 @@ while true; do
 
 	echo "WORKTIME ${LOOPSLEEPMS_LASTWORK}" || exit
 
-	loopsleepms ${update_every}
+	loopsleepms "${update_every}"
 
 	[ ${gc} -gt ${exit_after} ] && exit 0
 done
